@@ -72,8 +72,8 @@ if (!$rcA && !$rcB) {
 }
 # -------------
 
-our $VERSION = '1.002'; # VERSION
-my $LAST_UPDATE = '1.000'; # manually update whenever code is changed
+our $VERSION = '1.003'; # VERSION
+our $LAST_UPDATE = '1.000'; # manually update whenever code is changed
 
 my $outfile = $0;
 if ($outfile =~ m#[\\/]([^\\/]+)$#) { $outfile = $1; }
